pub struct Accelerator { /* private fields */ }Expand description
A keyboard shortcut that consists of an optional combination
of modifier keys (provided by Modifiers and
one key (Code).
Warning
This struct cannot represent all shortcuts found on non-U.S. keyboard layouts and might
be deprecated in the future.
Please use KeyAccelerator instead.
Implementations
Sourceimpl Accelerator
impl Accelerator
Sourcepub fn new(mods: Option<Modifiers>, key: Code) -> Accelerator
pub fn new(mods: Option<Modifiers>, key: Code) -> Accelerator
Creates a new accelerator to define keyboard shortcuts throughout your application.
Only Modifiers::ALT, Modifiers::SHIFT, Modifiers::CONTROL, and Modifiers::SUPER