pub struct KeyAccelerator { /* private fields */ }Expand description
A keyboard shortcut based on logical Key values.
Unlike Accelerator which uses physical Code keys,
KeyAccelerator uses logical Key values which can represent
any character including Unicode characters like +, €, {, etc.
Examples
They can be created directly
let accel = KeyAccelerator::new(Some(Modifiers::CONTROL), Key::Character("+".into()));or converted from an existing Accelerator
let old_accel = Accelerator::new(Some(Modifiers::CONTROL), Code::KeyC);
let new_accel: KeyAccelerator = old_accel.into();or parsed from a string, which supports literal character keys
let accel: KeyAccelerator = "Ctrl++".parse().unwrap();
let accel2: KeyAccelerator = "Ctrl+€".parse().unwrap();Implementations
Sourceimpl KeyAccelerator
impl KeyAccelerator
Sourcepub fn new(mods: Option<Modifiers>, key: Key) -> KeyAccelerator
pub fn new(mods: Option<Modifiers>, key: Key) -> KeyAccelerator
Creates a new key accelerator to define keyboard shortcuts throughout your application.
Only Modifiers::ALT, Modifiers::SHIFT, Modifiers::CONTROL, and Modifiers::SUPER